==> ngcp-rest-api_13.5.1.4+0~mr13.5.1.4.tar.xz: ngcp-rest-api-13.5.1.4+0~mr13.5.1.4/src/entities/db/provisioning/index.ts <==
export {VoipContractPreference} from './voip-contract-preference.mariadb.entity'
export {VoipContractSpeedDial} from './voip-contract-speed-dial.mariadb.entity'
export {VoipDBAlias} from './voip-dbalias.mariadb.entity'
export {VoipDomain} from './voip-domain.mariadb.entity'
export {VoipDomPreference} from './voip-dom-preference.mariadb.entity'
export {VoipHeaderRule} from './voip-header-rule.mariadb.entity'
export {VoipHeaderRuleSet} from './voip-header-rule-set.mariadb.entity'
export {VoipHeaderRuleCondition} from './voip-header-rule-condition.mariadb.entity'
export {VoipHeaderRuleAction} from './voip-header-rule-action.mariadb.entity'
export {VoipHeaderRuleConditionValue} from './voip-header-rule-condition-value.mariadb.entity'
export {VoipPbxGroup} from './voip-pbx-group.mariadb.entity'
export {VoipPeeringGroup} from './voip-peering-group.mariadb.entity'
export {VoipPeeringServer} from './voip-peering-server.mariadb.entity'
export {VoipPreference} from './voip-preference.mariadb.entity'
export {VoipProfPreference} from './voip-prof-preference.mariadb.entity'
export {VoipRewriteRule} from './voip-rewrite-rule.mariadb.entity'
export {VoipRewriteRuleSet} from './voip-rewrite-rule-set.mariadb.entity'
export {VoipSubscriber} from './voip-subscriber.mariadb.entity'
export {VoipSubscriberWebPasswordJournal} from './voip-subscriber-webpassword-journal.mariadb.entity'
export {VoipTimeSet} from './voip-time-set.mariadb.entity'
export {VoipUsrPreference} from './voip-usr-preference.mariadb.entity'
export {XmlGroup} from './xml-group.mariadb.entity'
export {XmlHost} from './xml-host.mariadb.entity'
export {XmlQueue} from './xml-queue.mariadb.entity'

==> ngcp-rest-api_14.0.1.1+0~mr14.0.1.1.tar.xz: ngcp-rest-api-14.0.1.1+0~mr14.0.1.1/src/entities/db/provisioning/index.ts <==
export {VoipContractPreference} from './voip-contract-preference.mariadb.entity'
export {VoipContractSpeedDial} from './voip-contract-speed-dial.mariadb.entity'
export {VoipDBAlias} from './voip-dbalias.mariadb.entity'
export {VoipDomain} from './voip-domain.mariadb.entity'
export {VoipDomPreference} from './voip-dom-preference.mariadb.entity'
export {VoipHeaderRule} from './voip-header-rule.mariadb.entity'
export {VoipHeaderRuleSet} from './voip-header-rule-set.mariadb.entity'
export {VoipHeaderRuleCondition} from './voip-header-rule-condition.mariadb.entity'
export {VoipHeaderRuleAction} from './voip-header-rule-action.mariadb.entity'
export {VoipHeaderRuleConditionValue} from './voip-header-rule-condition-value.mariadb.entity'
export {VoipPbxGroup} from './voip-pbx-group.mariadb.entity'
export {VoipPeeringGroup} from './voip-peering-group.mariadb.entity'
export {VoipPeeringInboundRule} from './voip-peering-inbound-rule.mariadb.entity'
export {VoipPeeringRule} from './voip-peering-rule.mariadb.entity'
export {VoipPeeringServer} from './voip-peering-server.mariadb.entity'
export {VoipPreference} from './voip-preference.mariadb.entity'
export {VoipProfPreference} from './voip-prof-preference.mariadb.entity'
export {VoipRewriteRule} from './voip-rewrite-rule.mariadb.entity'
export {VoipRewriteRuleSet} from './voip-rewrite-rule-set.mariadb.entity'
export {VoipSubscriber} from './voip-subscriber.mariadb.entity'
export {VoipSubscriberWebPasswordJournal} from './voip-subscriber-webpassword-journal.mariadb.entity'
export {VoipTimeSet} from './voip-time-set.mariadb.entity'
export {VoipUsrPreference} from './voip-usr-preference.mariadb.entity'
export {XmlGroup} from './xml-group.mariadb.entity'
export {XmlHost} from './xml-host.mariadb.entity'
export {XmlQueue} from './xml-queue.mariadb.entity'
